
%   C
%  / \
% S - R
%  \/
%  W

clear all
C = 1; S = 2; R = 3; W = 4; N = 4;
sizes = 2*ones(1,N);
potentials = {factorMake([C S R], [2 2 2], rand(2,2,2)), ...
	      factorMake([S R W], [2 2 2], rand(2,2,2))};
false = 1; true = 2;

%%%%%%%%%%% naive inference

[F1, Z] = naiveInfer(potentials, []);

[F2, alpha2] = naiveInfer(potentials, [S R]);
assert(approxeq(Z, alpha2)) % since no evidence

evSunif = factorMake(S, sizes(S), [0.5 0.5]); % uninformative local evidence
[F3, alpha3] = naiveInfer({potentials{:}, evSunif}, [S R]);
assert(approxeq(F3.T, F2.T)) % since evidence didn't change anything

evS = factorMake(S, sizes(S), [0 1]); % S in state 2
[F4, alpha4] = naiveInfer({potentials{:}, evS}, [S R]);
assert(approxeq(F4.T(1,1), 0)) % since S is in state 2
assert(approxeq(F4.T(1,2), 0)) % since S is in state 2


%%%%%%%%%%% var Elim

[F1ve, Zve] = varElim(potentials, []);
assert(approxeq(F1.T, F1ve.T))
assert(approxeq(Z, Zve))

[F2ve, alpha2ve] = varElim(potentials, [S R]);
assert(approxeq(F2.T, F2ve.T))
assert(approxeq(alpha2, alpha2ve))

evSunif = factorMake(S, sizes(S), [0.5 0.5]); % uninformative local evidence
[F3ve, alpha3ve] = varElim({potentials{:}, evSunif}, [S R]);
assert(approxeq(F3.T, F3ve.T))
assert(approxeq(alpha3, alpha3ve))

evS = factorMake(S, sizes(S), [0 1]); % S in state 2
[F4ve, alpha4ve] = varElim({potentials{:}, evS}, [S R]);
assert(approxeq(F4.T, F4ve.T))
assert(approxeq(alpha4, alpha4ve))
